/*
    clock.h (Nethack-Player/Recorder) Version 1.0
    Copyright (C) 2000 by Helge Dennhardt
    <Helge.Dennhardt@gmx.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


/* The (simulated) clock measures time in 1/100th of a second.
   An unsigned 32 bit integer should be enough for time measuring. */
typedef unsigned long TIME; 

/* The (simulated) clock runs at a certain speed which is normal speed
   times a multiplicator. For this multiplicator an unsigned 8 bit
   integer should be more than enough. */
typedef unsigned char SPEED;

/* Sets the (simulated) clock to <Time>. This clock will run <Speed>
   times faster than real time. */ 
void StartClock(TIME Time, SPEED Speed);

/* Reads out the current time of the (simulated) clock.*/
TIME GetTime();

/* Reads out the current speed multiplicator of the (simulated) clock.*/
SPEED GetSpeed();




